| Title: | Wrapper for R Package kwb.heatsine for OpenCPU Usage |
|---|---|
| Description: | Contains higher level functions build on top of R package kwb.heatsine for connecting with OpenCPU. |
| Authors: | Michael Rustler [aut, cre] (ORCID: <https://orcid.org/0000-0003-0647-7726>), Ralf Junghanns [aut], Hauke Sonnenberg [ctb] (ORCID: <https://orcid.org/0000-0001-9134-2871>), Smart-Control [fnd], Kompetenzzentrum Wasser Berlin gGmbH (KWB) [cph] |
| Maintainer: | Michael Rustler <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-31 08:13:27 UTC |
| Source: | https://github.com/KWB-R/kwb.heatsine.opencpu |
test dataset generated with R script (data-raw/DATASET.R)
data(json_args)data(json_args)
A json list with all parameters used by run_optimisation, which are passed to run_optimisation
json_argsjson_args
JSON wrapper function for kwb.heatsine::run_optimisation
run_optimisation( data_sw_selected, data_gw_selected, retardation_factor = 1.8, sw_monitoring_id = attr(data_sw_selected, "monitoring_id"), gw_monitoring_id = attr(data_gw_selected, "monitoring_id"), limits = c(100, 500), tolerance = 0.001, debug = FALSE )run_optimisation( data_sw_selected, data_gw_selected, retardation_factor = 1.8, sw_monitoring_id = attr(data_sw_selected, "monitoring_id"), gw_monitoring_id = attr(data_gw_selected, "monitoring_id"), limits = c(100, 500), tolerance = 0.001, debug = FALSE )
data_sw_selected |
data.frame with daily data temperature data of surface water monitoring point with columns "date" (format: "YYYY-MM-DD") and "value" (format: double, temperature in degree Celsius) for selected time period |
data_gw_selected |
data.frame with daily data temperature data of groundwater monitoring point with columns "date" (format: "YYYY-MM-DD") and "value" (format: double, temperature in degree Celsius) for selected time period |
retardation_factor |
hydraulic retardation factor (default: 2) |
sw_monitoring_id |
optional label for surface water monitoring id (default: "surface-water monitoring point"
or attr(data_sw_selected, "monitoring_id") if data imported with |
gw_monitoring_id |
optional label for groundwater monitoring id (default: "surface-water monitoring point"
or attr(data_sw_selected, "monitoring_id") if data imported with |
limits |
minimum/maximum period length for sinus optimisation in days (default: c(100, 500)) |
tolerance |
the desired accuracy (default: 0.001 |
debug |
show debug messages (default: FALSE) |
json list with sim/observation data ("data") fit parameters ("paras"), goodness-of-fit values ("gof") traveltimes ("traveltimes") and special (min, max, turning) points ("points") as returned by get_predictions